use Yandex::Translate;

my $key = "your_yandex_key";

my $tr = Yandex::Translate->new;

$tr->set_key($key);

$tr->set_text('In the name of God');

$tr->set_from_lang('en');

$tr->set_to_lang('ar');

print $tr->translate();
